"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from delphix.api.gateway.model_utils import (  # noqa: F401
    ApiTypeError,
    ModelComposed,
    ModelNormal,
    ModelSimple,
    cached_property,
    change_keys_js_to_python,
    convert_js_args_to_python_args,
    date,
    datetime,
    file_type,
    none_type,
    validate_get_composed_info,
)
from ..model_utils import OpenApiModel
from delphix.api.gateway.exceptions import ApiAttributeError


def lazy_import():
    from delphix.api.gateway.model.target_job_type import TargetJobType
    from delphix.api.gateway.model.target_object_type import TargetObjectType
    from delphix.api.gateway.model.virtualization_job_event import VirtualizationJobEvent
    globals()['TargetJobType'] = TargetJobType
    globals()['TargetObjectType'] = TargetObjectType
    globals()['VirtualizationJobEvent'] = VirtualizationJobEvent


class VirtualizationJob(ModelNormal):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Attributes:
      allowed_values (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          with a capitalized key describing the allowed value and an allowed
          value. These dicts store the allowed enum values.
      attribute_map (dict): The key is attribute name
          and the value is json key in definition.
      discriminator_value_class_map (dict): A dict to go from the discriminator
          variable value to the discriminator class name.
      validations (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          that stores validations for max_length, min_length, max_items,
          min_items, exclusive_maximum, inclusive_maximum, exclusive_minimum,
          inclusive_minimum, and regex.
      additional_properties_type (tuple): A tuple of classes accepted
          as additional properties values.
    """

    allowed_values = {
        ('job_state',): {
            'RUNNING': "RUNNING",
            'COMPLETED': "COMPLETED",
            'SUSPENDED': "SUSPENDED",
            'CANCELED': "CANCELED",
            'FAILED': "FAILED",
        },
    }

    validations = {
    }

    @cached_property
    def additional_properties_type():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded
        """
        lazy_import()
        return (bool, date, datetime, dict, float, int, list, str, none_type,)  # noqa: E501

    _nullable = False

    @cached_property
    def openapi_types():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded

        Returns
            openapi_types (dict): The key is attribute name
                and the value is attribute type.
        """
        lazy_import()
        return {
            'engine_job_id': (str,),  # noqa: E501
            'engine_id': (str,),  # noqa: E501
            'legacy_job_type': (str,),  # noqa: E501
            'job_type': (TargetJobType,),  # noqa: E501
            'target_object_id': (str,),  # noqa: E501
            'legacy_target_object_type': (str,),  # noqa: E501
            'target_object_type': (TargetObjectType,),  # noqa: E501
            'job_state': (str,),  # noqa: E501
            'start_time': (datetime,),  # noqa: E501
            'update_time': (datetime,),  # noqa: E501
            'suspendable': (bool,),  # noqa: E501
            'cancelable': (bool,),  # noqa: E501
            'queued': (bool,),  # noqa: E501
            'title': (str,),  # noqa: E501
            'cancel_reason': (str,),  # noqa: E501
            'percent_complete': (int,),  # noqa: E501
            'run_duration': (int,),  # noqa: E501
            'events': ([VirtualizationJobEvent],),  # noqa: E501
        }

    @cached_property
    def discriminator():
        return None


    attribute_map = {
        'engine_job_id': 'engine_job_id',  # noqa: E501
        'engine_id': 'engine_id',  # noqa: E501
        'legacy_job_type': 'legacy_job_type',  # noqa: E501
        'job_type': 'job_type',  # noqa: E501
        'target_object_id': 'target_object_id',  # noqa: E501
        'legacy_target_object_type': 'legacy_target_object_type',  # noqa: E501
        'target_object_type': 'target_object_type',  # noqa: E501
        'job_state': 'job_state',  # noqa: E501
        'start_time': 'start_time',  # noqa: E501
        'update_time': 'update_time',  # noqa: E501
        'suspendable': 'suspendable',  # noqa: E501
        'cancelable': 'cancelable',  # noqa: E501
        'queued': 'queued',  # noqa: E501
        'title': 'title',  # noqa: E501
        'cancel_reason': 'cancel_reason',  # noqa: E501
        'percent_complete': 'percent_complete',  # noqa: E501
        'run_duration': 'run_duration',  # noqa: E501
        'events': 'events',  # noqa: E501
    }

    read_only_vars = {
    }

    _composed_schemas = {}

    @classmethod
    @convert_js_args_to_python_args
    def _from_openapi_data(cls, *args, **kwargs):  # noqa: E501
        """VirtualizationJob - a model defined in OpenAPI

        Keyword Args:
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
            engine_job_id (str): ID of the virtualization engine job.. [optional]  # noqa: E501
            engine_id (str): ID of the RegisteredEngine.. [optional]  # noqa: E501
            legacy_job_type (str): Legacy type of the job.. [optional]  # noqa: E501
            job_type (TargetJobType): [optional]  # noqa: E501
            target_object_id (str): ID of the target object.. [optional]  # noqa: E501
            legacy_target_object_type (str): Legacy type of the target object.. [optional]  # noqa: E501
            target_object_type (TargetObjectType): [optional]  # noqa: E501
            job_state (str): [optional]  # noqa: E501
            start_time (datetime): The time the job started.. [optional]  # noqa: E501
            update_time (datetime): The time the job was last updated.. [optional]  # noqa: E501
            suspendable (bool): Indicates whether the job can be suspended.. [optional]  # noqa: E501
            cancelable (bool): Indicates whether the job can be canceled.. [optional]  # noqa: E501
            queued (bool): Indicates whether the job is queued.. [optional]  # noqa: E501
            title (str): The title of the job.. [optional]  # noqa: E501
            cancel_reason (str): The reason the job was canceled.. [optional]  # noqa: E501
            percent_complete (int): The percentage of the job that is complete.. [optional]  # noqa: E501
            run_duration (int): The time this job took to complete in milliseconds.. [optional]  # noqa: E501
            events ([VirtualizationJobEvent]): The events associated with this job.. [optional]  # noqa: E501
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        self = super(OpenApiModel, cls).__new__(cls)

        if args:
            raise ApiTypeError(
                "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                    args,
                    self.__class__.__name__,
                ),
                path_to_item=_path_to_item,
                valid_classes=(self.__class__,),
            )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
        return self

    required_properties = set([
        '_data_store',
        '_check_type',
        '_spec_property_naming',
        '_path_to_item',
        '_configuration',
        '_visited_composed_classes',
    ])

    @convert_js_args_to_python_args
    def __init__(self, *args, **kwargs):  # noqa: E501
        """VirtualizationJob - a model defined in OpenAPI

        Keyword Args:
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
            engine_job_id (str): ID of the virtualization engine job.. [optional]  # noqa: E501
            engine_id (str): ID of the RegisteredEngine.. [optional]  # noqa: E501
            legacy_job_type (str): Legacy type of the job.. [optional]  # noqa: E501
            job_type (TargetJobType): [optional]  # noqa: E501
            target_object_id (str): ID of the target object.. [optional]  # noqa: E501
            legacy_target_object_type (str): Legacy type of the target object.. [optional]  # noqa: E501
            target_object_type (TargetObjectType): [optional]  # noqa: E501
            job_state (str): [optional]  # noqa: E501
            start_time (datetime): The time the job started.. [optional]  # noqa: E501
            update_time (datetime): The time the job was last updated.. [optional]  # noqa: E501
            suspendable (bool): Indicates whether the job can be suspended.. [optional]  # noqa: E501
            cancelable (bool): Indicates whether the job can be canceled.. [optional]  # noqa: E501
            queued (bool): Indicates whether the job is queued.. [optional]  # noqa: E501
            title (str): The title of the job.. [optional]  # noqa: E501
            cancel_reason (str): The reason the job was canceled.. [optional]  # noqa: E501
            percent_complete (int): The percentage of the job that is complete.. [optional]  # noqa: E501
            run_duration (int): The time this job took to complete in milliseconds.. [optional]  # noqa: E501
            events ([VirtualizationJobEvent]): The events associated with this job.. [optional]  # noqa: E501
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        if args:
            raise ApiTypeError(
                "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                    args,
                    self.__class__.__name__,
                ),
                path_to_item=_path_to_item,
                valid_classes=(self.__class__,),
            )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
            if var_name in self.read_only_vars:
                raise ApiAttributeError(f"`{var_name}` is a read-only attribute. Use `from_openapi_data` to instantiate "
                                     f"class with read only attributes.")
