"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import delphix.api.gateway
from delphix.api.gateway.model.create_role import CreateRole
from delphix.api.gateway.model.permission_object import PermissionObject
from delphix.api.gateway.model.role_all_of import RoleAllOf
from delphix.api.gateway.model.tag import Tag
globals()['CreateRole'] = CreateRole
globals()['PermissionObject'] = PermissionObject
globals()['RoleAllOf'] = RoleAllOf
globals()['Tag'] = Tag
from delphix.api.gateway.model.role import Role


class TestRole(unittest.TestCase):
    """Role unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testRole(self):
        """Test Role"""
        # FIXME: construct object with mandatory attributes with example values
        # model = Role()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
